"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseGenerator = void 0;
const js_yaml_1 = __importDefault(require("js-yaml"));
const yeoman_generator_1 = __importDefault(require("yeoman-generator"));
class BaseGenerator extends yeoman_generator_1.default {
    constructor(args, options, features) {
        super(args, options, Object.assign({ customInstallTask: true }, features));
        this.copyTemplate = (from, to, context) => {
            this.fs.copyTpl(this.templatePath(from), this.destinationPath(to), context);
        };
        this.questions = [];
        this.answers = {};
        this.queueMethod(this.initializeQuestions.bind(this), "initializeQuestions", "initializing");
        this.queueMethod(this.askQuestions.bind(this), "askQuestions", "prompting");
        this.queueMethod(this.initializeSubGenerators.bind(this), "initializeSubGenerators", "prompting");
    }
    composeWith(generators, options, returnNewGenerator) {
        return super.composeWith(generators, options, returnNewGenerator);
    }
    async addDevDependencyWithComment(dependency) {
        return this.addDevDependenciesWithComments([dependency]);
    }
    async addDevDependenciesWithComments(dependencies) {
        const dependenciesWithVersions = {};
        const dependenciesWithoutVersions = [];
        const dependencyComments = {};
        for (const { name, comment, version } of dependencies) {
            if (version) {
                dependenciesWithVersions[name] = version;
            }
            else {
                dependenciesWithoutVersions.push(name);
            }
            dependencyComments[name] = comment;
        }
        this.extendPackageJson({ devDependenciesComments: dependencyComments });
        await super.addDevDependencies(dependenciesWithVersions);
        await super.addDevDependencies(dependenciesWithoutVersions);
    }
    addDevDependencies(dependencies) {
        return super.addDevDependencies(dependencies);
    }
    extendPackageJson(json) {
        this.fs.extendJSON(this.destinationPath("package.json"), json);
    }
    writeOrAppendGitignore(from) {
        const content = this.readTemplate(from);
        this.writeOrAppendDestination(".gitignore", content, {
            leadingNewlineOnAppend: true,
        });
    }
    loadConfig(configFilePath) {
        const configContents = this.fs.read(configFilePath);
        const config = js_yaml_1.default.load(configContents);
        this.options = Object.assign(Object.assign({}, this.options), config);
    }
    configureSubGenerators() {
        return [];
    }
    initializeQuestions() {
        const getQuestions = this.constructor.getQuestions;
        const questions = getQuestions !== undefined ? getQuestions() : [];
        this.addQuestions(questions);
    }
    async askQuestions() {
        const answers = this.questions.length > 0 ? await this.prompt(this.questions) : {};
        this.answers = Object.assign(Object.assign({}, this.answers), answers);
    }
    initializeSubGenerators() {
        const subGenerators = this.configureSubGenerators();
        this.composeWithSubGenerators(subGenerators);
    }
    addQuestions(questions) {
        for (const question of questions) {
            this.addQuestionOrCopyOption(question);
        }
    }
    addQuestionOrCopyOption(question) {
        const name = question.name;
        const option = this.options[name];
        if (option === undefined) {
            this.questions.push(question);
        }
        else {
            this.answers[name] = option;
        }
    }
    composeWithSubGenerators(subGenerators) {
        return super.composeWith(subGenerators, Object.assign(Object.assign({}, this.options), this.answers), true);
    }
    writeOrAppendDestination(to, content, options = {}) {
        this.writeOrAppend(this.destinationPath(to), content, options);
    }
    writeOrAppend(to, content, options = {}) {
        if (this.fs.exists(to)) {
            if (options.leadingNewlineOnAppend === true) {
                content = `\n${content}`;
            }
            return this.fs.append(to, content);
        }
        this.fs.write(to, content);
    }
}
exports.BaseGenerator = BaseGenerator;
//# sourceMappingURL=BaseGenerator.js.map